Changelog

### 1.0.0 (2019-09-06)

  * Initial public release

### 1.1.0 (2019-10-08)

  * IE support
  * **Describe** & **About** popups
  * Custom CLI support

### 1.1.1 (2019-10-23)

  * [#13](https://github.com/manahl/dtale/issues/13): fix for auto-detection of column widths for strings and floats
